# awsneo

Library for python 3 that allows you to connect to different database engines (PostgreSQL, MySQL, MSSQL) through secrets manager (secret values) or direct connection, also allows you to execute queries from scripts in buckets or directly as a single query

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install foobar.

```bash
pip install awsneo
```

## Usage

```python

```

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License
[MIT](https://choosealicense.com/licenses/mit/)